@@ -7,6 +7,10 @@ use Moose;
 
 extends 'Machine::State::Failure::Transition';
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
+
+method _build_message {
+    "Transition execution failure."
+}
 
 1;
