@@ -7,12 +7,16 @@ use Moose;
 
 extends 'Machine::State::Failure::Transition';
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
-has hook => (
+has hook_name => (
     is       => 'ro',
     isa      => 'Str',
-    required => 1
+    required => 0,
 );
 
+method _build_message {
+    "Transition hooking failure."
+}
+
 1;
